"""
Библиотека для взаимодействия с моделями AI через API.

Основные функции:
    - ask: Отправляет запрос к модели и возвращает ответ.
    - answer: Отправляет запрос к модели и выводит ответ в консоль.
    - get: Возвращает содержимое определённого текстового файла с ДЗ.
>>> from danya import ask, answer, get
"""

from .main import answer, ask, get
